package com.jqtx.windows.job;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.CharsetUtil;
import cn.hutool.extra.ssh.Sftp;
import com.jqtx.infrastructure.oss.starter.config.OssUtils;
import com.jqtx.windows.component.LoanPlanComponent;
import com.jqtx.windows.component.RedeemComponent;
import com.jqtx.windows.component.model.LoanPlanModel;
import com.jqtx.windows.component.model.RedeemModel;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Component
@Slf4j
public class RedeemJob {

    @Autowired
    private OssUtils ossUtils;

    @Autowired
    private LoanPlanComponent loanPlanComponent;

    @Autowired
    private RedeemComponent redeemComponent;

    @XxlJob("redeemJob")
    public void run() {
        String param = XxlJobHelper.getJobParam();
        Sftp sftp = new Sftp("115.238.89.106", 9901, "xiaohua_fr", "R7MADMx1lwMN5k4v", CharsetUtil.CHARSET_UTF_8);
        String date = DateUtil.format(new Date(), "yyyyMMdd");
        if (StringUtils.isNotEmpty(param)) {
            date = param;
        }
        if (sftp.isDir("/download/compensatory/" + date)) {
            sftp.cd("/download/compensatory/" + date);
            sftp.get("compensatory_" + date + ".txt", "/compensatory_sftp.txt");
            ossUtils.ossUpload("ZN/compensatory/" + "compensatory_" + date + ".txt", FileUtil.file("/compensatory_sftp.txt"));
            FileUtil.del("/compensatory_sftp.txt");
            String stringObject = ossUtils.getStringObject("ZN/compensatory/" + "compensatory_" + date + ".txt");
            log.info("oss代偿数据:{}", stringObject);
            redeemComponent.insert(getlist(stringObject));
        } else {
            log.info("浙农代偿文件不存在:{}", date);
        }

    }

    /**
     * 封装model
     *
     * @param jsonResult
     * @return
     */
    private List<RedeemModel> getlist(String jsonResult) {
        ArrayList<RedeemModel> list = new ArrayList<>();
        String[] split = jsonResult.split("\n");
        if (split == null) {
            return list;
        }
        for (String modelstr : split) {
            String[] split1 = modelstr.split("\\|");
            RedeemModel model = new RedeemModel();
            model.setLoanNo(split1[0]);
            model.setPlanNo(getPlanNo(split1[0], split1[2]));
            model.setRedeemType(split1[1]);
            model.setPlanIndex(split1[2]);
            model.setRaiseTime(split1[3]);
            model.setBackedTime(split1[4]);
            model.setHoldDay(split1[5]);
            model.setRedeemBen(split1[6]);
            model.setRedeemXi(split1[7]);
            model.setRedeemFa(split1[8]);
            model.setRedeemAmount(split1[9]);
            list.add(model);
        }
        return list;
    }

    /**
     * 获取planNo
     *
     * @param loanNo
     * @param planIndex
     * @return
     */
    private String getPlanNo(String loanNo, String planIndex) {
        LoanPlanModel planModel = loanPlanComponent.getPlanNoByLoan(loanNo, planIndex);
        return planModel.getPlanNo();
    }

}
